<!DOCTYPE html>
<html lang="pt-br">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1, user-scalable=no">
  <link rel="stylesheet" href="{{ url_for('static', filename='css/style.css') }}">
  {% block head %}
  {% endblock %}
</head>
<body>
  {% block content %}
  {% endblock %}
  {% block scripts %}
  {% endblock %}
</body>
</html>
