:root {
  font-size: 20px;
}

@media(max-width: 600px) {
  :root {
    font-size: 17px;
  }
}

* {
  box-sizing: border-box;
  margin: 0;
  padding: 0;
  font-size: 1rem;
  font-weight: normal;
}

li {
  list-style: none;
}

a {
  text-decoration: none;
}
